==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/functions_77.js <==
var searchData=
[
  ['w3d',['w3d',['../classplstream.html#a66f2583f5f748c663508269dd00c1100',1,'plstream::w3d()'],['../classplplot_1_1core_1_1PLStream.html#ab9cace93368bb2c75e80bc40ea614880',1,'plplot.core.PLStream.w3d()']]],
  ['width',['width',['../classplstream.html#a7a993bd850c9dc8d7f3fab51b544c778',1,'plstream::width()'],['../classplplot_1_1core_1_1PLStream.html#a33e0353dc3495c37f208c58d1206b3bc',1,'plplot.core.PLStream.width()']]],
  ['wind',['wind',['../classplstream.html#a01d10b709219154e2cd6f7d8920ba95d',1,'plstream::wind()'],['../classplplot_1_1core_1_1PLStream.html#a9ff162968aefdc6773fb263e09fdf02c',1,'plplot.core.PLStream.wind()']]],
  ['wr_5fcommand',['wr_command',['../plbuf_8c.html#af4896eb58fe07c91ea761a8a360ba06a',1,'plbuf.c']]],
  ['wr_5fdata',['wr_data',['../plbuf_8c.html#ad513629816f783d949b03054d3a78872',1,'plbuf.c']]],
  ['write_5fhex',['write_hex',['../svg_8c.html#a6bd0dd7904fdd34fb887d3cdfc70511e',1,'svg.c']]],
  ['write_5fto_5fstream',['write_to_stream',['../cairo_8c.html#ad9101ac10ca83db3a0ad930aa2d3bf67',1,'cairo.c']]],
  ['write_5funicode',['write_unicode',['../svg_8c.html#a70c144e4dd3764dc26b900589d0b9040',1,'svg.c']]],
  ['wx_5fdefine_5farray',['WX_DEFINE_ARRAY',['../wxwidgets_8h.html#ac1a4f9bf8e1be723e2607be5d73feda1',1,'wxwidgets.h']]],
  ['wx_5fset_5fbuffer',['wx_set_buffer',['../wxwidgets_8h.html#ab28e3bfaaa5fa87f81c7fa0f8f4b9003',1,'wxwidgets.h']]],
  ['wx_5fset_5fdc',['wx_set_dc',['../wxwidgets_8h.html#a01560f348183083351fa4edc2a5d669f',1,'wxwidgets.h']]],
  ['wx_5fset_5fsize',['wx_set_size',['../wxwidgets_8cpp.html#ada45d19fe091fcd5cdf52563aa8fe0b0',1,'wx_set_size(PLStream *pls, int width, int height):&#160;wxwidgets.cpp'],['../wxwidgets_8h.html#ada45d19fe091fcd5cdf52563aa8fe0b0',1,'wx_set_size(PLStream *pls, int width, int height):&#160;wxwidgets.cpp']]],
  ['wxgetsizedialog',['wxGetSizeDialog',['../classwxGetSizeDialog.html#abe896fc13fe390477415bf7cf6a90814',1,'wxGetSizeDialog']]],
  ['wxpldevbase',['wxPLDevBase',['../classwxPLDevBase.html#a4187aaa44dfa649f08c2e4f4f4b05593',1,'wxPLDevBase']]],
  ['wxpldevdc',['wxPLDevDC',['../classwxPLDevDC.html#a2600ad9a1bc65bf546282426e067b158',1,'wxPLDevDC']]],
  ['wxplplotframe',['wxPLplotFrame',['../classwxPLplotFrame.html#a490223778698f716930525e87ae343d5',1,'wxPLplotFrame']]],
  ['wxplplotstream',['wxPLplotstream',['../classwxPLplotstream.html#a9a49ebca924e07eaf2c2ee46e2284ddf',1,'wxPLplotstream::wxPLplotstream()'],['../classwxPLplotstream.html#a990615daa9c632a1911597e06d67b07f',1,'wxPLplotstream::wxPLplotstream(wxDC *dc, int width, int height, int style=wxPLPLOT_NONE)']]],
  ['wxplplotwindow',['wxPLplotWindow',['../classwxPLplotWindow.html#a23c573a13c657f4abd519564f35f9264',1,'wxPLplotWindow::wxPLplotWindow()'],['../classwxPLplotwindow.html#a366b1e4dd28fc92906a6d42ae05921c4',1,'wxPLplotwindow::wxPLplotwindow()']]],
  ['wxrunapp',['wxRunApp',['../wxwidgets_8cpp.html#ae167b1d3de0eb51170ce3027f17e4965',1,'wxwidgets.cpp']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/functions_77.js <==
var searchData=
[
  ['w3d',['w3d',['../classplstream.html#a66f2583f5f748c663508269dd00c1100',1,'plstream::w3d()'],['../classplplot_1_1core_1_1PLStream.html#ab9cace93368bb2c75e80bc40ea614880',1,'plplot.core.PLStream.w3d()']]],
  ['width',['width',['../classplstream.html#a7a993bd850c9dc8d7f3fab51b544c778',1,'plstream::width()'],['../classplplot_1_1core_1_1PLStream.html#a55792ad22e042bc8f3a0ea8f1effb401',1,'plplot.core.PLStream.width(double width)'],['../classplplot_1_1core_1_1PLStream.html#a33e0353dc3495c37f208c58d1206b3bc',1,'plplot.core.PLStream.width(int width)']]],
  ['wind',['wind',['../classplstream.html#a01d10b709219154e2cd6f7d8920ba95d',1,'plstream::wind()'],['../classplplot_1_1core_1_1PLStream.html#a9ff162968aefdc6773fb263e09fdf02c',1,'plplot.core.PLStream.wind()']]],
  ['wr_5fcommand',['wr_command',['../plbuf_8c.html#af4896eb58fe07c91ea761a8a360ba06a',1,'plbuf.c']]],
  ['wr_5fdata',['wr_data',['../plbuf_8c.html#ad513629816f783d949b03054d3a78872',1,'plbuf.c']]],
  ['write_5fhex',['write_hex',['../svg_8c.html#a6bd0dd7904fdd34fb887d3cdfc70511e',1,'svg.c']]],
  ['write_5fto_5fstream',['write_to_stream',['../cairo_8c.html#ad9101ac10ca83db3a0ad930aa2d3bf67',1,'cairo.c']]],
  ['write_5funicode',['write_unicode',['../svg_8c.html#a70c144e4dd3764dc26b900589d0b9040',1,'svg.c']]],
  ['wx_5fset_5fbuffer',['wx_set_buffer',['../wxwidgets_8h.html#ab28e3bfaaa5fa87f81c7fa0f8f4b9003',1,'wxwidgets.h']]],
  ['wx_5fset_5fdc',['wx_set_dc',['../wxwidgets_8h.html#a01560f348183083351fa4edc2a5d669f',1,'wxwidgets.h']]],
  ['wxpldevice',['wxPLDevice',['../classwxPLDevice.html#af7dc862026548d46a2aa11c2d09f7642',1,'wxPLDevice']]],
  ['wxplplotstream',['wxPLplotstream',['../classwxPLplotstream.html#a9a49ebca924e07eaf2c2ee46e2284ddf',1,'wxPLplotstream::wxPLplotstream()'],['../classwxPLplotstream.html#a990615daa9c632a1911597e06d67b07f',1,'wxPLplotstream::wxPLplotstream(wxDC *dc, int width, int height, int style=wxPLPLOT_NONE)']]],
  ['wxplplotwindow',['wxPLplotwindow',['../classwxPLplotwindow.html#aa1d1a9dc96341c115360dead33d6be18',1,'wxPLplotwindow']]]
];
